import  cv2
import glob

def is_rgb_image(image):
    return len(image.shape) == 3 and image.shape[-1] == 3

def is_grayscale_image(image):
    return (len(image.shape) == 2) or (len(image.shape) == 3 and image.shape[-1] == 1)

def read_images(path):
    images=[]
    files = glob.glob (path+"/*.jpg")
    for myFile in files:
        image = cv2.imread(myFile)
        images.append(image)
    return images

def read_image(path):
    image=[cv2.imread(path)]
    return image
def export(images,path,base="img"):
    i=0
    res=True
    for im in images:
        i+=1
        img_name='/'+base+str(i)+'.jpg'
        res=cv2.imwrite(path+img_name,im) and res
    return res


import random
from abc import ABC, abstractmethod
from typing import List
import numpy as np


class BasicTransform(ABC):
    def check_images(self, images):
        for im in images:
            if not (isinstance(im, np.ndarray)):
                raise TypeError

    @abstractmethod
    def transform(self, images):
        pass


class DummyTransformation(BasicTransform):
    def transform(self, images: List[np.ndarray]):
        self.check_images(images)
        return images

class Flip(BasicTransform):
    def __init__(self,V=-1,H=1):
        self.V=V
        self.H=H
    def transform(self, images: List[np.ndarray]):
        self.check_images(images)
        res = []
        for im in images:
            res.append(im[::self.V, ::self.H, :])
        return res

class Flip_Vertical(BasicTransform):
    def transform(self, images: List[np.ndarray]):
        self.check_images(images)
        res=[]
        for im in images:
            res.append(im[::-1,:,:])
        return res
class Flip_Horizental(BasicTransform):
    def transform(self, images: List[np.ndarray]):
        self.check_images(images)
        res=[]
        for im in images:
            res.append(im[:,::-1,:])
        return res

class RandomRotation90(BasicTransform):
    def __init__(self,factor=random.randint(0, 3)):
        self.factor=factor

    def transform(self, images: List[np.ndarray]):
        self.check_images(images)
        res=[]
        for im in images:
            switcher = {
                0: im,
                1: np.transpose(im, (1, 0, 2))[:, ::-1, :],
                2: np.transpose(im, (1, 0, 2))[::-1, :, :],
                3: im[::-1,:,:]
            }
            res.append(switcher.get(self.factor))
        return res


from setuptools import find_packages,setup

setup(
    name='TunAugmentor',
    packages=find_packages(include=['TunAugmentor']),
    version='0.1.3',
    description='Python library for image data augmentation',
    author='Ahmed Belgacem, Firas Meddeb',
    author_email = 'ahmedbelgaacem@gmail.com',
    url="https://github.com/ahmedbelgacem/TunAugmentor",
    download_url ="https://github.com/ahmedbelgacem/TunAugmentor/archive/refs/tags/0.1.2.tar.gz",
    license='MIT',
    install_requires=['numpy','opencv-python'],
    setup_requires=['pytest-runner'],
    tests_require=['pytest==4.4.1'],
    test_suite='tests',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License'
    ],
)
